//
// Copyright (c) 2012, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Windows.Forms;


namespace MindFusion.Diagramming.WinForms.Samples.CS.FlowCharter
{
	/// <summary>
	/// Summary description for OptionsDialog.
	/// </summary>
	public partial class OptionsDialog : Form
	{
		public OptionsDialog()
		{
			InitializeComponent();
		}

		private void OnLoad(object sender, System.EventArgs e)
		{
			_showGridCheck.Checked = ShowGrid;

			_anchorColorPicker = new ColorPicker();
			_anchorColorPicker.Color = AnchorColor;
			_anchorColorPicker.Location = _anchorColorHidden.Location;
			_anchorColorPicker.Size = _anchorColorHidden.Size;
			_anchorColorPicker.Click += new System.EventHandler(this.AnchorColorPicker_OnClick);

			_backColorPicker = new ColorPicker();
			_backColorPicker.Color = BackgroundColor;
			_backColorPicker.Location = _backColorHidden.Location;
			_backColorPicker.Size = _backColorHidden.Size;
			_backColorPicker.Click += new System.EventHandler(this.BackColorPicker_OnClick);

			_nodeColorPicker = new ColorPicker();
			_nodeColorPicker.Color = NodeColor;
			_nodeColorPicker.Location = _nodeColorHidden.Location;
			_nodeColorPicker.Size = _nodeColorHidden.Size;
			_nodeColorPicker.Click += new System.EventHandler(this.NodeColorPicker_OnClick);

			_connectorColorPicker = new ColorPicker();
			_connectorColorPicker.Color = ConnectorColor;
			_connectorColorPicker.Location = _connectorColorHidden.Location;
			_connectorColorPicker.Size = _connectorColorHidden.Size;
			_connectorColorPicker.Click += new System.EventHandler(this.ConnectorColorPicker_OnClick);

			_anchorsGroup.Controls.Add(_anchorColorPicker);
			this.Controls.Add(_backColorPicker);
			this.Controls.Add(_nodeColorPicker);
			this.Controls.Add(_connectorColorPicker);

			// Initialize controls' values
			_showAnchorsCheck.Checked = ShowAnchors;
			_circleBtn.Pushed = (AnchorStyle == 0);
			_rectBtn.Pushed = (AnchorStyle == 1);
			_xBtn.Pushed = (AnchorStyle == 2);
		}

		private void AnchorStyleToolbar_OnButtonClicked(object sender, System.Windows.Forms.ToolBarButtonClickEventArgs e)
		{
			_circleBtn.Pushed = false;
			_rectBtn.Pushed = false;
			_xBtn.Pushed = false;

			e.Button.Pushed = true;
		}

		private void OnOK(object sender, System.EventArgs e)
		{
			ShowGrid = _showGridCheck.Checked;
			ShowAnchors = _showAnchorsCheck.Checked;
			if(_circleBtn.Pushed) AnchorStyle = 0;
			if(_rectBtn.Pushed) AnchorStyle = 1;
			if(_xBtn.Pushed) AnchorStyle = 2;

			BackgroundColor = _backColorPicker.Color;
			NodeColor = _nodeColorPicker.Color;
			ConnectorColor = _connectorColorPicker.Color;
			AnchorColor = _anchorColorPicker.Color;

			this.Close();
		}

		private void AnchorColorPicker_OnClick(object sender, System.EventArgs e)
		{
			_colorDialog.Color = _anchorColorPicker.Color;

			if(_colorDialog.ShowDialog(this) == DialogResult.OK)
				_anchorColorPicker.Color = _colorDialog.Color;
		}

		private void BackColorPicker_OnClick(object sender, System.EventArgs e)
		{
			_colorDialog.Color = _backColorPicker.Color;

			if(_colorDialog.ShowDialog(this) == DialogResult.OK)
				_backColorPicker.Color = _colorDialog.Color;
		}

		private void NodeColorPicker_OnClick(object sender, System.EventArgs e)
		{
			_colorDialog.Color = _nodeColorPicker.Color;

			if(_colorDialog.ShowDialog(this) == DialogResult.OK)
				_nodeColorPicker.Color = _colorDialog.Color;
		}

		private void ConnectorColorPicker_OnClick(object sender, System.EventArgs e)
		{
			_colorDialog.Color = _connectorColorPicker.Color;

			if(_colorDialog.ShowDialog(this) == DialogResult.OK)
				_connectorColorPicker.Color = _colorDialog.Color;
		}


		public bool ShowGrid
		{
			get { return _showGrid; }
			set { _showGrid = value; }
		}
		public Color BackgroundColor
		{
			get { return _backColor; }
			set { _backColor = value; }
		}
		public Color NodeColor
		{
			get { return _nodeColor; }
			set { _nodeColor = value; }
		}
		public Color ConnectorColor
		{
			get { return _connectorColor; }
			set { _connectorColor = value; }
		}

		public bool ShowAnchors
		{
			get { return _showAnchors; }
			set { _showAnchors = value; }
		}
		public Color AnchorColor
		{
			get { return _anchorColor; }
			set { _anchorColor = value; }
		}
		public int AnchorStyle
		{
			get { return _anchorStyle; }
			set { _anchorStyle = value; }
		}


		private bool _showGrid;
		private Color _backColor;
		private Color _nodeColor;
		private Color _connectorColor;

		private bool _showAnchors;
		private Color _anchorColor;
		private System.Windows.Forms.ColorDialog _colorDialog;
		private System.Windows.Forms.CheckBox _showGridCheck;
		private int _anchorStyle;
	}
}
